@@ -1,7 +1,7 @@
 #!/bin/bash -e
 
 # clones all reps depending on $baseBranch
-# parameter: $baseBranch
+# parameter: baseBranch = $1
 
 # clone all repos except droolsjbpm-build-bootstrap as this is supposed to be cloned before this script and has to be available
-./droolsjbpm-build-bootstrap/script/git-clone-others.sh --branch $baseBranch --depth 70
\ No newline at end of file
+./droolsjbpm-build-bootstrap/script/git-clone-others.sh --branch $1 --depth 70
\ No newline at end of file
